/* logger.vala
 * Copyright (c) 2012, Sebastian Reichel <sre@ring0.de>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

static const string create_cmd = "CREATE TABLE log (id INTEGER PRIMARY KEY ASC, temperature_indoor INTEGER, temperature_outdoor INTEGER, humidity_indoor INTEGER, humidity_outdoor INTEGER, pressure INTEGER, wind_average INTEGER, wind_gust INTEGER, wind_direction INTEGER, rain INTEGER);";
static const string insert_cmd = "INSERT INTO log (\"temperature_indoor\", \"temperature_outdoor\", \"humidity_indoor\", \"humidity_outdoor\", \"pressure\", \"wind_average\", \"wind_gust\", \"wind_direction\", \"rain\") VALUES (\"%u\", \"%u\", \"%u\", \"%u\", \"%u\", \"%u\", \"%u\", \"%u\", \"%u\");";

public static int main(string[] args) {
	Sqlite.Database db;
	var station = new Weather.Station();

	if(args.length < 2) {
		stderr.printf("Usage: %s /path/to/database\n", args[0]);
		return 1;
	}

	if(station == null) {
		stderr.printf("weather station not found!\n");
		return 1;
	}

	if (!FileUtils.test (args[1], FileTest.IS_REGULAR)) {
		stderr.printf ("Database %s does not exist or is directory\n", args[1]);
		return 1;
	}

	if(Sqlite.Database.open(args[1], out db) != Sqlite.OK) {
		stderr.printf ("Can't open database: %s\n", db.errmsg ());
		return 1;
	}

	var header = station.read_header();
	var data = station.read_data(header.history_data_stack);

	db.exec(create_cmd);
	db.exec(insert_cmd.printf(data.temperature_indoor, data.temperature_outdoor, data.humidity_indoor, data.humidity_outdoor, data.pressure, data.avg_wind_speed, data.gust_wind_speed, data.wind_direction, data.rain));

	return 0;
}
